@@ -6,10 +6,11 @@ import (
 	"fmt"
 	"os"
 	"path/filepath"
+	"slices"
 	"strconv"
 	"strings"
 
-	incus "github.com/lxc/incus/shared/util"
+	incus "github.com/lxc/incus/v6/shared/util"
 	"golang.org/x/sys/unix"
 
 	"github.com/lxc/distrobuilder/shared"
@@ -20,6 +21,7 @@ type vm struct {
 	loopDevice string
 	rootFS     string
 	rootfsDir  string
+	bootfsDir  string
 	size       uint64
 	ctx        context.Context
 }
@@ -29,7 +31,7 @@ func newVM(ctx context.Context, imageFile, rootfsDir, fs string, size uint64) (*
 		fs = "ext4"
 	}
 
-	if !incus.ValueInSlice(fs, []string{"btrfs", "ext4"}) {
+	if !slices.Contains([]string{"btrfs", "ext4"}, fs) {
 		return nil, fmt.Errorf("Unsupported fs: %s", fs)
 	}
 
@@ -60,6 +62,35 @@ func (v *vm) getUEFIDevFile() string {
 	return fmt.Sprintf("%sp1", v.loopDevice)
 }
 
+func (v *vm) findRootfsDevUUID() (rootUUID string, err error) {
+	rootfsDevFile := v.getRootfsDevFile()
+	if rootfsDevFile == "" {
+		err = fmt.Errorf("Failed to get rootfs device name.")
+		return
+	}
+
+	var out strings.Builder
+	if err = shared.RunCommand(v.ctx, nil, &out, "blkid", "-o", "export", rootfsDevFile); err != nil {
+		err = fmt.Errorf("Failed to get rootfs device UUID: %w", err)
+		return
+	}
+
+	fields := strings.Fields(out.String())
+	for _, field := range fields {
+		if strings.HasPrefix(field, "UUID=") {
+			rootUUID = field
+			break
+		}
+	}
+
+	if rootUUID == "" {
+		err = fmt.Errorf("No rootfs device UUID found")
+		return
+	}
+
+	return
+}
+
 func (v *vm) createEmptyDiskImage() error {
 	f, err := os.Create(v.imageFile)
 	if err != nil {
@@ -81,11 +112,12 @@ func (v *vm) createEmptyDiskImage() error {
 	return nil
 }
 
-func (v *vm) createPartitions() error {
-	args := [][]string{
-		{"--zap-all"},
-		{"--new=1::+100M", "-t 1:EF00"},
-		{"--new=2::", "-t 2:8300"},
+func (v *vm) createPartitions(args ...[]string) error {
+	if len(args) == 0 {
+		args = [][]string{
+			{"--zap-all"},
+			{"--new=1::+100M", "-t 1:EF00"},
+			{"--new=2::", "-t 2:8300"}}
 	}
 
 	for _, cmd := range args {
@@ -98,75 +130,120 @@ func (v *vm) createPartitions() error {
 	return nil
 }
 
-func (v *vm) mountImage() error {
+func (v *vm) lsblkLoopDevice() (parseMajorMinor func(int) (uint32, uint32, error), num int, err error) {
+	var out strings.Builder
+	// Ensure the partitions are accessible. This part is usually only needed
+	// if building inside of a container.
+	err = shared.RunCommand(v.ctx, nil, &out, "lsblk", "--raw", "--output", "MAJ:MIN", "--noheadings", v.loopDevice)
+	if err != nil {
+		err = fmt.Errorf("Failed to list block devices: %w", err)
+		return
+	}
+
+	lsblkOutput := strings.TrimSpace(out.String())
+	// Output sample:
+	// 7:1    -- loop device
+	// 259:2  -- partition 1
+	// 259:3  -- partition 2
+	deviceNumbers := strings.Split(lsblkOutput, "\n")
+	num = len(deviceNumbers)
+	parseMajorMinor = func(i int) (major, minor uint32, err error) {
+		if i >= num {
+			err = fmt.Errorf("failed to parse major minor for %d >= %d", i, num)
+			return
+		}
+
+		fields := strings.Split(deviceNumbers[i], ":")
+		num, err := strconv.Atoi(fields[0])
+		if err != nil {
+			err = fmt.Errorf("Failed to parse %q: %w", fields[0], err)
+			return
+		}
+
+		major = uint32(num)
+		num, err = strconv.Atoi(fields[1])
+		if err != nil {
+			err = fmt.Errorf("Failed to parse %q: %w", fields[1], err)
+			return
+		}
+
+		minor = uint32(num)
+		return
+	}
+
+	return
+}
+
+func (v *vm) losetup() (err error) {
+	var out strings.Builder
+	err = shared.RunCommand(v.ctx, nil, &out, "losetup", "-P", "-f", "--show", v.imageFile)
+	if err != nil {
+		err = fmt.Errorf("Failed to setup loop device: %w", err)
+		return
+	}
+
+	err = shared.RunCommand(v.ctx, nil, nil, "udevadm", "settle")
+	if err != nil {
+		err = fmt.Errorf("Failed to wait loop device ready: %w", err)
+		return
+	}
+
+	v.loopDevice = strings.TrimSpace(out.String())
+	return
+}
+
+func (v *vm) mountImage() (err error) {
 	// If loopDevice is set, it probably is already mounted.
 	if v.loopDevice != "" {
 		return nil
 	}
 
-	var out strings.Builder
-
-	err := shared.RunCommand(v.ctx, nil, &out, "losetup", "-P", "-f", "--show", v.imageFile)
+	err = v.losetup()
 	if err != nil {
-		return fmt.Errorf("Failed to setup loop device: %w", err)
+		return err
 	}
 
-	v.loopDevice = strings.TrimSpace(out.String())
-
-	out.Reset()
-
-	// Ensure the partitions are accessible. This part is usually only needed
-	// if building inside of a container.
-	err = shared.RunCommand(v.ctx, nil, &out, "lsblk", "--raw", "--output", "MAJ:MIN", "--noheadings", v.loopDevice)
+	parseMajorMinor, num, err := v.lsblkLoopDevice()
 	if err != nil {
-		return fmt.Errorf("Failed to list block devices: %w", err)
+		return
+	} else if num != 3 {
+		err = fmt.Errorf("Failed to list block devices")
+		return
 	}
 
-	deviceNumbers := strings.Split(out.String(), "\n")
-
 	if !incus.PathExists(v.getUEFIDevFile()) {
-		fields := strings.Split(deviceNumbers[1], ":")
-
-		major, err := strconv.Atoi(fields[0])
+		var major, minor uint32
+		major, minor, err = parseMajorMinor(1)
 		if err != nil {
-			return fmt.Errorf("Failed to parse %q: %w", fields[0], err)
-		}
-
-		minor, err := strconv.Atoi(fields[1])
-		if err != nil {
-			return fmt.Errorf("Failed to parse %q: %w", fields[1], err)
+			return
 		}
 
 		dev := unix.Mkdev(uint32(major), uint32(minor))
 
 		err = unix.Mknod(v.getUEFIDevFile(), unix.S_IFBLK|0644, int(dev))
 		if err != nil {
-			return fmt.Errorf("Failed to create block device %q: %w", v.getUEFIDevFile(), err)
+			err = fmt.Errorf("Failed to create block device %q: %w", v.getUEFIDevFile(), err)
+			return
 		}
 	}
 
 	if !incus.PathExists(v.getRootfsDevFile()) {
-		fields := strings.Split(deviceNumbers[2], ":")
-
-		major, err := strconv.Atoi(fields[0])
+		var major, minor uint32
+		major, minor, err = parseMajorMinor(2)
 		if err != nil {
-			return fmt.Errorf("Failed to parse %q: %w", fields[0], err)
-		}
-
-		minor, err := strconv.Atoi(fields[1])
-		if err != nil {
-			return fmt.Errorf("Failed to parse %q: %w", fields[1], err)
+			return
 		}
 
 		dev := unix.Mkdev(uint32(major), uint32(minor))
 
 		err = unix.Mknod(v.getRootfsDevFile(), unix.S_IFBLK|0644, int(dev))
 		if err != nil {
-			return fmt.Errorf("Failed to create block device %q: %w", v.getRootfsDevFile(), err)
+			err = fmt.Errorf("Failed to create block device %q: %w", v.getRootfsDevFile(), err)
+			return
 		}
 	}
 
-	return nil
+	return
 }
 
 func (v *vm) umountImage() error {
@@ -220,7 +297,7 @@ func (v *vm) createRootFS() error {
 		}
 
 		defer func() {
-			_ = shared.RunCommand(v.ctx, nil, nil, "umount", v.rootfsDir)
+			_ = v.umountPartition(v.rootfsDir)
 		}()
 
 		return shared.RunCommand(v.ctx, nil, nil, "btrfs", "subvolume", "create", fmt.Sprintf("%s/@", v.rootfsDir))
@@ -259,12 +336,30 @@ func (v *vm) mountUEFIPartition() error {
 		return errors.New("Disk image not mounted")
 	}
 
-	mountpoint := filepath.Join(v.rootfsDir, "boot", "efi")
+	v.bootfsDir = filepath.Join(v.rootfsDir, "boot", "efi")
 
-	err := os.MkdirAll(mountpoint, 0755)
+	err := os.MkdirAll(v.bootfsDir, 0755)
 	if err != nil {
-		return fmt.Errorf("Failed to create directory %q: %w", mountpoint, err)
+		return fmt.Errorf("Failed to create directory %q: %w", v.bootfsDir, err)
 	}
 
-	return shared.RunCommand(v.ctx, nil, nil, "mount", "-t", "vfat", v.getUEFIDevFile(), mountpoint, "-o", "discard")
+	return shared.RunCommand(v.ctx, nil, nil, "mount", "-t", "vfat", v.getUEFIDevFile(), v.bootfsDir, "-o", "discard")
+}
+
+func (v *vm) umountPartition(mountpoint string) (err error) {
+	err = v.checkMountpoint(mountpoint)
+	if err != nil {
+		return
+	}
+
+	return shared.RunCommand(v.ctx, nil, nil, "umount", "-R", mountpoint)
+}
+
+func (v *vm) checkMountpoint(mountpoint string) (err error) {
+	err = shared.RunCommand(v.ctx, nil, nil, "mountpoint", mountpoint)
+	if err != nil {
+		err = fmt.Errorf("%s not mounted: %w", mountpoint, err)
+	}
+
+	return err
 }
