@@ -6,8 +6,8 @@ import (
 	"path/filepath"
 	"strings"
 
-	"github.com/flosch/pongo2"
-	"github.com/lxc/incus/shared/api"
+	"github.com/flosch/pongo2/v4"
+	"github.com/lxc/incus/v6/shared/api"
 
 	"github.com/lxc/distrobuilder/image"
 	"github.com/lxc/distrobuilder/shared"
