@@ -8,7 +8,7 @@ import (
 	"strings"
 	"time"
 
-	incus "github.com/lxc/incus/shared/util"
+	incus "github.com/lxc/incus/v6/shared/util"
 
 	"github.com/lxc/distrobuilder/shared"
 )
