@@ -41,9 +41,10 @@ type managerCommands struct {
 
 // Manager represents a package manager.
 type Manager struct {
-	mgr manager
-	def shared.Definition
-	ctx context.Context
+	mgr    manager
+	def    shared.Definition
+	ctx    context.Context
+	logger *logrus.Logger
 }
 
 type manager interface {
@@ -64,7 +65,7 @@ var managers = map[string]func() manager{
 	"dnf":        func() manager { return &dnf{} },
 	"egoportage": func() manager { return &egoportage{} },
 	"equo":       func() manager { return &equo{} },
-	"luet":       func() manager { return &luet{} },
+	"anise":      func() manager { return &anise{} },
 	"opkg":       func() manager { return &opkg{} },
 	"pacman":     func() manager { return &pacman{} },
 	"portage":    func() manager { return &portage{} },
@@ -90,7 +91,7 @@ func Load(ctx context.Context, managerName string, logger *logrus.Logger, defini
 		return nil, fmt.Errorf("Failed to load manager %q: %w", managerName, err)
 	}
 
-	return &Manager{def: definition, mgr: d, ctx: ctx}, nil
+	return &Manager{def: definition, mgr: d, ctx: ctx, logger: logger}, nil
 }
 
 // ManagePackages manages packages.
@@ -122,6 +123,8 @@ func (m *Manager) ManagePackages(imageTarget shared.ImageTarget) error {
 			return fmt.Errorf("Failed to update: %w", err)
 		}
 
+		m.logger.WithField("trigger", "post-update").Info("Running hooks")
+
 		// Run post update hook
 		for _, action := range m.def.GetRunnableActions("post-update", imageTarget) {
 			if action.Pongo {
@@ -164,7 +167,7 @@ func (m *Manager) ManagePackages(imageTarget shared.ImageTarget) error {
 func (m *Manager) ManageRepositories(imageTarget shared.ImageTarget) error {
 	var err error
 
-	if m.def.Packages.Repositories == nil || len(m.def.Packages.Repositories) == 0 {
+	if len(m.def.Packages.Repositories) == 0 {
 		return nil
 	}
 
