@@ -1,6 +1,8 @@
 package shared
 
 import (
+	"os"
+
 	"github.com/sirupsen/logrus"
 )
 
@@ -8,8 +10,11 @@ import (
 func GetLogger(debug bool) (*logrus.Logger, error) {
 	logger := logrus.StandardLogger()
 
+	logger.SetOutput(os.Stdout)
+
 	formatter := logrus.TextFormatter{
 		FullTimestamp: true,
+		PadLevelText:  true,
 	}
 
 	logger.Formatter = &formatter
