@@ -159,40 +159,3 @@ func getLatestRelease(baseURL, release, arch string) (string, error) {
 
 	return "", errors.New("Failed to find latest release")
 }
-
-func getLatestCoreBaseImage(baseURL, release, arch string) (string, error) {
-	u, err := url.Parse(fmt.Sprintf("%s/ubuntu/%s/%s/default", baseURL, release, arch))
-	if err != nil {
-		return "", fmt.Errorf("Failed to parse URL %q: %w", fmt.Sprintf("%s/ubuntu/%s/%s/default", baseURL, release, arch), err)
-	}
-
-	var resp *http.Response
-
-	err = shared.Retry(func() error {
-		resp, err = http.Get(u.String())
-		if err != nil {
-			return fmt.Errorf("Failed to GET %q: %w", u.String(), err)
-		}
-
-		return nil
-	}, 3)
-	if err != nil {
-		return "", err
-	}
-
-	defer resp.Body.Close()
-
-	body, err := io.ReadAll(resp.Body)
-	if err != nil {
-		return "", fmt.Errorf("Failed to read body: %w", err)
-	}
-
-	regex := regexp.MustCompile(`\d{8}_\d{2}:\d{2}`)
-	releases := regex.FindAllString(string(body), -1)
-
-	if len(releases) > 1 {
-		return fmt.Sprintf("%s/%s/rootfs.tar.xz", u.String(), releases[len(releases)-1]), nil
-	}
-
-	return "", errors.New("Failed to find latest core base image")
-}
